@@ -134,7 +134,7 @@ class Atom:
         barnxs = {}
         cmxs = {}
         for kk in ['tot', 'pe', 'co', 'ra']:
-           spline = getattr(self, kk)
+           spline = getattr(self, f'{kk}_spl')
            icurve = interpolate.splev(ep, spline, der=0, ext=0)
            icurve_ua = np.divide(icurve, u*self.wt)
            barnxs[kk] = icurve
@@ -188,7 +188,7 @@ class Mixture:
         logger.info('X-ray energy (wavelength): %d eV (%.5f A)'\
                     %(energy, 12398.4/energy))
         logger.info('Sample thickness: %.5f cm' %(self.thick))
-        logger.info("""%-7s %-7s %-7s %-7s %-8s %-8s %-8s %-15s""" %('atom', 'wt frac', "f'", "f''", 'total xs', 'rayleigh', 'compton', 'phot+compton'))
+        logger.info(f"""{'atom':-7s} {'wt frac':-7s} {"f'":-7s} {"f''":-7s} {'total xs':-8s} {'rayleigh':-8s} {'compton':-8s} {'photoelectric':-15s} {'phot+compton':-15s}""")
         for w in self.stoi.keys():
             u = Atom(w)
             barnxs, cmxs = u.atom_mu(energy)
@@ -209,7 +209,7 @@ class Mixture:
                 sig_ua = cmxs['co']
             mix_sigma += sig_ua*self.weig[u.name]
             f1, f2 = u.atom_ff(energy)
-            logger.info('%-7s %-7.3f %-7.3f %-7.3f %-8.3f %-8.3f %-8.3f %-8.3f' \
+            logger.info('%-7s %-7.3f %-7.3f %-7.3f %-8.3f %-8.3f %-8.3f %-15.3f %-15.3f' \
                  %(u.name, self.weig[u.name], f1, f2,
                    barnxs['tot']*self.stoi[u.name],
                    (barnxs['pe']+barnxs['co'])*self.stoi[u.name],
